@@ -4,19 +4,16 @@
 #  License, v. 2.0. If a copy of the MPL was not distributed with this
 #  file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
-from dataclassy import dataclass
-
-from zepben.cimbend.tracing.queue import Queue
-from zepben.cimbend.traversals.tracing import BaseTraversal, SearchType, create_queue
+from zepben.cimbend.traversals.queue import Queue
+from zepben.cimbend.traversals.tracing import BaseTraversal
 from zepben.cimbend.traversals.tracker import Tracker
-from typing import Callable, Set, List, Awaitable, TypeVar
+from typing import Callable, Set, TypeVar, Optional
 import copy
 
 __all__ = ["BranchRecursiveTraversal"]
 T = TypeVar('T')
 
 
-@dataclass(slots=True)
 class BranchRecursiveTraversal(BaseTraversal[T]):
 
     queue_next: Callable[[T, BaseTraversal[T], Set[T]], None]
@@ -25,19 +22,24 @@ class BranchRecursiveTraversal(BaseTraversal[T]):
     optimisation to skip queuing."""
 
     branch_queue: Queue
+    """Queue containing branches to be processed"""
 
     process_queue: Queue
+    """Queue containing the items to process for this branch"""
 
     tracker: Tracker = Tracker()
-    parent: BaseTraversal = None
-    on_branch_start: Callable[[T], None] = None
+    """Tracker for the items in this branch"""
+
+    parent: Optional[BaseTraversal] = None
+    """The parent branch for this branch, None implies this branch has no parent"""
+
+    on_branch_start: Optional[Callable[[T], None]] = None
+    """A function to call at the start of each branches processing"""
 
     def __lt__(self, other):
         """
         This Traversal is Less than `other` if the starting item is less than other's starting item.
         This is used to dictate which branch is next to traverse in the branch_queue.
-        `other`
-        Returns
         """
         if self.start_item is not None and other.start_item is not None:
             return self.start_item < other.start_item
@@ -50,8 +52,8 @@ class BranchRecursiveTraversal(BaseTraversal[T]):
 
     def has_visited(self, item: T):
         """
-        Check whether item has been visited before. An item is visited if this traversal or any parent has
-        visited it.
+        Check whether item has been visited before. An item is visited if this traversal or any parent has visited it.
+
         `item` The item to check
         Returns True if the item has been visited once.
         """
@@ -89,6 +91,7 @@ class BranchRecursiveTraversal(BaseTraversal[T]):
                 await t.trace()
 
     def reset(self):
+        """Reset the run state, queues and tracker for this this traversal"""
         self._reset_run_flag()
         self.process_queue.queue.clear()
         self.branch_queue.queue.clear()
@@ -100,24 +103,22 @@ class BranchRecursiveTraversal(BaseTraversal[T]):
         pass this `Traversal` as the parent. The new Traversal will be :meth:`reset` prior to being returned.
         Returns A new `BranchRecursiveTraversal` the same as this, but with this Traversal as its parent
         """
-        branch = BranchRecursiveTraversal(self.queue_next,
-                                          branch_queue=copy.deepcopy(self.branch_queue),
-                                          tracker=copy.deepcopy(self.tracker),
+        branch = BranchRecursiveTraversal(queue_next=self.queue_next,
+                                          branch_queue=self.branch_queue.copy(),
+                                          tracker=self.tracker.copy(),
                                           parent=self,
                                           on_branch_start=self.on_branch_start,
-                                          step_actions=copy.deepcopy(self.step_actions),
-                                          stop_conditions=copy.deepcopy(self.stop_conditions))
-        branch.process_queue = copy.deepcopy(self.process_queue)
+                                          process_queue=self.process_queue.copy(),
+                                          step_actions=list(self.step_actions),
+                                          stop_conditions=list(self.stop_conditions))
         branch.reset()
         return branch
 
     async def _run_trace(self, can_stop_on_start_item: bool = True):
         """
-        Run's the trace. Stop conditions and step_actions are called with await, so you can utilise asyncio when
-        performing a trace if your step actions or conditions are IO intensive. Stop conditions and
-        step actions will always be called for each item in the order provided.
-        `can_stop_on_start_item` Whether the trace can stop on the start_item. Actions will still be applied to
-                                       the start_item.
+        Run's the trace. Stop conditions and step_actions are called with await, so you can utilise asyncio when performing a trace if your step actions or
+        conditions are IO intensive. Stop conditions and step actions will always be called for each item in the order provided.
+        `can_stop_on_start_item` Whether the trace can stop on the start_item. Actions will still be applied to the start_item.
         """
         # Unroll first iteration of loop to handle can_stop_on_start_item = True
         if self.start_item is None:
